@@ -54,6 +54,7 @@
 #include "MagickCore/monitor.h"
 #include "MagickCore/monitor-private.h"
 #include "MagickCore/option.h"
+#include "MagickCore/profile-private.h"
 #include "MagickCore/property.h"
 #include "MagickCore/resource_.h"
 #include "MagickCore/static.h"
@@ -275,6 +276,50 @@ static inline void JXLInitImage(Image *image,JxlBasicInfo *basic_info)
     }
 }
 
+static inline MagickBooleanType JXLPatchExifProfile(StringInfo *exif_profile)
+{
+  size_t
+    exif_length;
+
+  StringInfo
+    *snippet;
+
+  unsigned char
+    *exif_datum;
+
+  unsigned int
+    offset=0;
+
+  if (GetStringInfoLength(exif_profile) < 4)
+    return(MagickFalse);
+
+  /*
+    Extract and cache Exif profile.
+  */
+  snippet=SplitStringInfo(exif_profile,4);
+  offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+0)) << 24;
+  offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+1)) << 16;
+  offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+2)) << 8;
+  offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+3)) << 0;
+  snippet=DestroyStringInfo(snippet);
+  /*
+    Strip any EOI marker if payload starts with a JPEG marker.
+  */
+  exif_length=GetStringInfoLength(exif_profile);
+  exif_datum=GetStringInfoDatum(exif_profile);
+  if ((exif_length > 2) && 
+      ((memcmp(exif_datum,"\xff\xd8",2) == 0) ||
+        (memcmp(exif_datum,"\xff\xe1",2) == 0)) &&
+      (memcmp(exif_datum+exif_length-2,"\xff\xd9",2) == 0))
+    SetStringInfoLength(exif_profile,exif_length-2);
+  /*
+    Skip to actual Exif payload.
+  */
+  if (offset < GetStringInfoLength(exif_profile))
+    (void) DestroyStringInfo(SplitStringInfo(exif_profile,offset));
+  return(MagickTrue);
+}
+
 static Image *ReadJXLImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   Image
@@ -537,19 +582,23 @@ static Image *ReadJXLImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #endif
         if (jxl_status != JXL_DEC_SUCCESS)
           break;
-        profile=AcquireStringInfo(profile_size);
-#if JPEGXL_NUMERIC_VERSION >= JPEGXL_COMPUTE_NUMERIC_VERSION(0,9,0)
-        jxl_status=JxlDecoderGetColorAsICCProfile(jxl_info,
-          JXL_COLOR_PROFILE_TARGET_ORIGINAL,GetStringInfoDatum(profile),
-          profile_size);
+        profile=AcquireProfileStringInfo("icm",profile_size,exception);
+        if (profile != (StringInfo *) NULL)
+          {
+  #if JPEGXL_NUMERIC_VERSION >= JPEGXL_COMPUTE_NUMERIC_VERSION(0,9,0)
+            jxl_status=JxlDecoderGetColorAsICCProfile(jxl_info,
+              JXL_COLOR_PROFILE_TARGET_ORIGINAL,GetStringInfoDatum(profile),
+              profile_size);
 #else
-        jxl_status=JxlDecoderGetColorAsICCProfile(jxl_info,&pixel_format,
-          JXL_COLOR_PROFILE_TARGET_ORIGINAL,GetStringInfoDatum(profile),
-          profile_size);
+            jxl_status=JxlDecoderGetColorAsICCProfile(jxl_info,&pixel_format,
+              JXL_COLOR_PROFILE_TARGET_ORIGINAL,GetStringInfoDatum(profile),
+              profile_size);
 #endif
-        if (jxl_status == JXL_DEC_SUCCESS)
-          (void) SetImageProfile(image,"icm",profile,exception);
-        profile=DestroyStringInfo(profile);
+            if (jxl_status == JXL_DEC_SUCCESS)
+              (void) SetImageProfilePrivate(image,profile,exception);
+            else
+              profile=DestroyStringInfo(profile);
+          }
         if (jxl_status == JXL_DEC_SUCCESS)
           jxl_status=JXL_DEC_COLOR_ENCODING;
         break;
@@ -652,7 +701,8 @@ static Image *ReadJXLImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Read Exif profile.
             */
-            exif_profile=AcquireStringInfo((size_t) size);
+            exif_profile=AcquireProfileStringInfo("exif",(size_t) size,
+              exception);
             jxl_status=JxlDecoderSetBoxBuffer(jxl_info,
               GetStringInfoDatum(exif_profile),size);
           }
@@ -661,7 +711,8 @@ static Image *ReadJXLImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Read XMP profile.
             */
-            xmp_profile=AcquireStringInfo((size_t) size);
+            xmp_profile=AcquireProfileStringInfo("xmp",(size_t) size,
+              exception);
             jxl_status=JxlDecoderSetBoxBuffer(jxl_info,
               GetStringInfoDatum(xmp_profile),size);
           }
@@ -682,56 +733,15 @@ static Image *ReadJXLImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   }
   (void) JxlDecoderReleaseBoxBuffer(jxl_info);
-  if ((exif_profile != (StringInfo *) NULL) &&
-      (GetStringInfoLength(exif_profile) > 4))
+  if (exif_profile != (StringInfo *) NULL)
     {
-      size_t
-        exif_length;
-
-      StringInfo
-        *snippet;
-
-      unsigned char
-        *exif_datum;
-
-      unsigned int
-        offset=0;
-
-      /*
-        Extract and cache Exif profile.
-      */
-      snippet=SplitStringInfo(exif_profile,4);
-      offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+0)) << 24;
-      offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+1)) << 16;
-      offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+2)) << 8;
-      offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+3)) << 0;
-      snippet=DestroyStringInfo(snippet);
-      /*
-        Strip any EOI marker if payload starts with a JPEG marker.
-      */
-      exif_length=GetStringInfoLength(exif_profile);
-      exif_datum=GetStringInfoDatum(exif_profile);
-      if ((exif_length > 2) && 
-          ((memcmp(exif_datum,"\xff\xd8",2) == 0) ||
-           (memcmp(exif_datum,"\xff\xe1",2) == 0)) &&
-          (memcmp(exif_datum+exif_length-2,"\xff\xd9",2) == 0))
-        SetStringInfoLength(exif_profile,exif_length-2);
-      /*
-        Skip to actual Exif payload.
-      */
-      if (offset < GetStringInfoLength(exif_profile))
-        (void) DestroyStringInfo(SplitStringInfo(exif_profile,offset));
-      (void) SetImageProfile(image,"exif",exif_profile,exception);
-      exif_profile=DestroyStringInfo(exif_profile);
+      if (JXLPatchExifProfile(exif_profile) != MagickFalse)
+        (void) SetImageProfilePrivate(image,exif_profile,exception);
+      else
+        exif_profile=DestroyStringInfo(exif_profile);
     }
   if (xmp_profile != (StringInfo *) NULL)
-    {
-      /*
-        Cache XMP profile.
-      */
-      (void) SetImageProfile(image,"xmp",xmp_profile,exception);
-      xmp_profile=DestroyStringInfo(xmp_profile);
-    }
+    (void) SetImageProfilePrivate(image,xmp_profile,exception);
   output_buffer=(unsigned char *) RelinquishMagickMemory(output_buffer);
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   if (runner != NULL)
